@@ -17,11 +17,9 @@ use Sub::Name qw(subname);
 
 use Devel::hdb::Router;
 
-use Devel::hdb::Logger qw(log);
-
 use vars qw( $parent_pid ); # when running in the test harness
 
-our $VERSION = '0.23_13';
+our $VERSION = '0.23_14';
 
 our $APP_OBJ;
 sub get {
@@ -212,9 +210,7 @@ sub notify_fork_parent {
         $env->{'psgix.harakiri.commit'} = Plack::Util::TRUE;
     };
     $self->{router}->once_after('POST','/announce_child', $gotit);
-log('entering run loop...');
     $self->run();
-log('left run loop');
     $self->step;
 }
 
@@ -271,9 +267,7 @@ sub app {
 
 sub run {
     my $self = shift;
-log('Entering run loop...');
     $self->{server}->run($self->app);
-log('left run loop');
     1;
 }
 *idle = \&run;
